@@ -1,6 +1,6 @@
 /* This is a generated file, don't edit */
 
-#define NUM_APPLETS 223
+#define NUM_APPLETS 227
 
 const char applet_names[] ALIGN1 = ""
 "[" "\0"
@@ -14,6 +14,7 @@ const char applet_names[] ALIGN1 = ""
 "ash" "\0"
 "awk" "\0"
 "basename" "\0"
+"bbconfig" "\0"
 "bunzip2" "\0"
 "bzcat" "\0"
 "bzip2" "\0"
@@ -24,17 +25,20 @@ const char applet_names[] ALIGN1 = ""
 "chown" "\0"
 "chpasswd" "\0"
 "chroot" "\0"
+"chrt" "\0"
 "chvt" "\0"
 "cksum" "\0"
 "clear" "\0"
 "cmp" "\0"
 "comm" "\0"
 "cp" "\0"
+"cpio" "\0"
 "crond" "\0"
 "crontab" "\0"
 "cryptpw" "\0"
 "cut" "\0"
 "date" "\0"
+"dc" "\0"
 "dd" "\0"
 "deallocvt" "\0"
 "delgroup" "\0"
@@ -71,6 +75,7 @@ const char applet_names[] ALIGN1 = ""
 "ftpget" "\0"
 "ftpput" "\0"
 "fuser" "\0"
+"getopt" "\0"
 "getty" "\0"
 "grep" "\0"
 "gunzip" "\0"
@@ -109,9 +114,7 @@ const char applet_names[] ALIGN1 = ""
 "login" "\0"
 "logname" "\0"
 "logread" "\0"
-"losetup" "\0"
 "ls" "\0"
-"lzmacat" "\0"
 "md5sum" "\0"
 "mesg" "\0"
 "microcom" "\0"
@@ -152,6 +155,8 @@ const char applet_names[] ALIGN1 = ""
 "realpath" "\0"
 "reboot" "\0"
 "renice" "\0"
+"reset" "\0"
+"resize" "\0"
 "rm" "\0"
 "rmdir" "\0"
 "route" "\0"
@@ -206,7 +211,6 @@ const char applet_names[] ALIGN1 = ""
 "unexpand" "\0"
 "uniq" "\0"
 "unix2dos" "\0"
-"unlzma" "\0"
 "unzip" "\0"
 "uptime" "\0"
 "usleep" "\0"
@@ -240,6 +244,7 @@ arping_main,
 ash_main,
 awk_main,
 basename_main,
+bbconfig_main,
 bunzip2_main,
 bunzip2_main,
 bzip2_main,
@@ -250,17 +255,20 @@ chmod_main,
 chown_main,
 chpasswd_main,
 chroot_main,
+chrt_main,
 chvt_main,
 cksum_main,
 clear_main,
 cmp_main,
 comm_main,
 cp_main,
+cpio_main,
 crond_main,
 crontab_main,
 cryptpw_main,
 cut_main,
 date_main,
+dc_main,
 dd_main,
 deallocvt_main,
 deluser_main,
@@ -297,6 +305,7 @@ fsck_main,
 ftpgetput_main,
 ftpgetput_main,
 fuser_main,
+getopt_main,
 getty_main,
 grep_main,
 gunzip_main,
@@ -335,9 +344,7 @@ logger_main,
 login_main,
 logname_main,
 logread_main,
-losetup_main,
 ls_main,
-unlzma_main,
 md5_sha1_sum_main,
 mesg_main,
 microcom_main,
@@ -378,6 +385,8 @@ readprofile_main,
 realpath_main,
 halt_main,
 renice_main,
+reset_main,
+resize_main,
 rm_main,
 rmdir_main,
 route_main,
@@ -432,7 +441,6 @@ uncompress_main,
 expand_main,
 uniq_main,
 dos2unix_main,
-unlzma_main,
 unzip_main,
 uptime_main,
 usleep_main,
@@ -466,217 +474,221 @@ const uint16_t applet_nameofs[] ALIGN2 = {
 0x0031,
 0x0035,
 0x003e,
-0x0046,
-0x004c,
-0x0052,
-0x0056,
-0x005a,
-0x0060,
-0x0066,
-0x006c,
+0x0047,
+0x004f,
+0x0055,
+0x005b,
+0x005f,
+0x0063,
+0x0069,
+0x006f,
 0x0075,
-0x007c,
-0x0081,
-0x0087,
-0x008d,
-0x0091,
-0x0096,
-0x0099,
-0x809f,
+0x007e,
+0x0085,
+0x008a,
+0x008f,
+0x0095,
+0x009b,
+0x009f,
+0x00a4,
 0x00a7,
-0x00af,
-0x00b3,
-0x00b8,
-0x00bb,
-0x00c5,
+0x00ac,
+0x80b2,
+0x00ba,
+0x00c2,
+0x00c6,
+0x00cb,
 0x00ce,
-0x00d6,
-0x00d9,
-0x00e3,
-0x00e8,
-0x00f0,
-0x80f6,
-0x00fb,
-0x0104,
-0x0107,
-0x0110,
-0x0115,
-0x0118,
-0x011e,
-0x0124,
-0x0128,
-0x0133,
+0x00d1,
+0x00db,
+0x00e4,
+0x00ec,
+0x00ef,
+0x00f9,
+0x00fe,
+0x0106,
+0x810c,
+0x0111,
+0x011a,
+0x011d,
+0x0126,
+0x012b,
+0x012e,
+0x0134,
 0x013a,
-0x013f,
-0x014a,
+0x013e,
+0x0149,
 0x0150,
-0x0156,
-0x015e,
-0x0167,
-0x016d,
-0x0173,
-0x0178,
+0x0155,
+0x0160,
+0x0166,
+0x016c,
+0x0174,
 0x017d,
-0x0182,
+0x0183,
+0x0189,
 0x018e,
 0x0193,
-0x019a,
-0x01a1,
-0x01a7,
-0x01ad,
-0x01b2,
-0x01b9,
-0x01be,
-0x01c3,
+0x0198,
+0x01a4,
+0x01a9,
+0x01b0,
+0x01b7,
+0x01bd,
+0x01c4,
 0x01ca,
 0x01cf,
-0x01d7,
-0x01de,
+0x01d6,
+0x01db,
+0x01e0,
 0x01e7,
-0x01ef,
-0x01f2,
+0x01ec,
+0x01f4,
 0x01fb,
-0x0202,
-0x0207,
-0x020d,
-0x0212,
-0x021a,
-0x8221,
-0x8227,
-0x022c,
-0x0231,
-0x0239,
-0x0242,
-0x0248,
-0x024d,
-0x0254,
-0x0259,
-0x0261,
-0x0269,
+0x0204,
+0x020c,
+0x020f,
+0x0218,
+0x021f,
+0x0224,
+0x022a,
+0x022f,
+0x0237,
+0x823e,
+0x8244,
+0x0249,
+0x024e,
+0x0256,
+0x025f,
+0x0265,
+0x026a,
 0x0271,
-0x0274,
-0x027d,
+0x0276,
+0x027e,
 0x0286,
-0x828d,
-0x0293,
-0x029b,
+0x028e,
+0x0291,
+0x029a,
 0x02a3,
-0x02ab,
-0x02ae,
-0x02b6,
-0x02bd,
-0x02c2,
-0x02cb,
-0x02d1,
+0x82aa,
+0x02b0,
+0x02b8,
+0x02c0,
+0x02c3,
+0x02ca,
+0x02cf,
 0x02d8,
 0x02de,
 0x02e5,
-0x02ec,
-0x42f1,
-0x02f7,
-0x0302,
-0x0305,
-0x030c,
+0x02eb,
+0x02f2,
+0x02f9,
+0x42fe,
+0x0304,
 0x030f,
-0x0317,
+0x0312,
+0x0319,
 0x031c,
-0x0323,
+0x0324,
 0x0329,
-0x0332,
-0x0335,
-0x833c,
-0x0343,
-0x0349,
-0x434f,
-0x0354,
-0x035a,
-0x0365,
-0x036b,
-0x0374,
-0x037d,
-0x0384,
-0x0387,
-0x038d,
+0x0330,
+0x0336,
+0x033f,
+0x0342,
+0x8349,
+0x0350,
+0x0356,
+0x435c,
+0x0361,
+0x0367,
+0x0372,
+0x0378,
+0x0381,
+0x038a,
 0x0391,
-0x0397,
-0x03a0,
-0x03ac,
-0x03b5,
-0x03bc,
-0x03c3,
-0x03c6,
-0x03cc,
-0x03d2,
+0x0394,
+0x039a,
+0x039e,
+0x03a4,
+0x03ad,
+0x03b9,
+0x03c2,
+0x03c9,
+0x03d0,
 0x03d6,
-0x03df,
+0x03dd,
+0x03e0,
 0x03e6,
-0x03ea,
-0x03ee,
-0x03f6,
-0x0401,
-0x040d,
-0x0414,
-0x0417,
-0x041f,
-0x0425,
-0x042a,
-0x0430,
-0x0442,
-0x0447,
-0x044f,
-0x8454,
-0x0457,
-0x045f,
-0x0463,
-0x046b,
-0x0472,
-0x047e,
-0x0483,
-0x048a,
-0x0492,
-0x0497,
-0x049b,
-0x049f,
-0x04a6,
-0x04ae,
-0x04b3,
-0x04b8,
-0x04be,
-0x04c3,
-0x04c7,
+0x03ec,
+0x03f0,
+0x03f9,
+0x0400,
+0x0404,
+0x0408,
+0x0410,
+0x041b,
+0x0427,
+0x042e,
+0x0431,
+0x0439,
+0x043f,
+0x0444,
+0x044a,
+0x045c,
+0x0461,
+0x0469,
+0x846e,
+0x0471,
+0x0479,
+0x047d,
+0x0485,
+0x048c,
+0x0498,
+0x049d,
+0x04a4,
+0x04ac,
+0x04b1,
+0x04b5,
+0x04b9,
+0x04c0,
+0x04c8,
 0x04cd,
-0x44d0,
-0x04db,
-0x04e0,
-0x04e4,
-0x04eb,
-0x04f2,
-0x04f9,
-0x0500,
-0x0506,
-0x0511,
+0x04d2,
+0x04d8,
+0x04dd,
+0x04e1,
+0x04e7,
+0x44ea,
+0x04f5,
+0x04fa,
+0x04fe,
+0x0505,
+0x050c,
+0x0513,
 0x051a,
-0x051f,
-0x0528,
-0x052f,
-0x0535,
-0x053c,
-0x0543,
-0x054c,
-0x0555,
-0x055d,
-0x8560,
-0x0566,
-0x056c,
-0x0575,
-0x0578,
-0x057d,
-0x0583,
-0x0587,
-0x058e,
-0x0594,
-0x0598,
-0x059d,
+0x0520,
+0x052b,
+0x0534,
+0x0539,
+0x0542,
+0x0548,
+0x054f,
+0x0556,
+0x055f,
+0x0568,
+0x0570,
+0x8573,
+0x0579,
+0x057f,
+0x0588,
+0x058b,
+0x0590,
+0x0596,
+0x059a,
+0x05a1,
+0x05a7,
+0x05ab,
+0x05b0,
 };
 const uint8_t applet_install_loc[] ALIGN1 = {
 0x33,
@@ -684,104 +696,106 @@ const uint8_t applet_install_loc[] ALIGN1 = {
 0x32,
 0x32,
 0x31,
+0x13,
+0x33,
+0x33,
+0x11,
+0x11,
+0x44,
+0x33,
+0x33,
+0x33,
+0x11,
+0x34,
+0x33,
+0x31,
+0x31,
+0x11,
+0x41,
+0x33,
+0x41,
+0x33,
+0x11,
+0x11,
+0x33,
+0x33,
+0x43,
+0x41,
+0x31,
+0x12,
+0x33,
+0x23,
+0x32,
+0x33,
+0x21,
+0x11,
+0x21,
+0x32,
+0x33,
+0x21,
+0x23,
+0x22,
+0x24,
+0x13,
+0x33,
+0x31,
+0x23,
+0x33,
+0x13,
+0x01,
+0x41,
+0x32,
+0x31,
+0x12,
+0x33,
+0x13,
+0x13,
+0x12,
+0x11,
+0x11,
+0x32,
+0x11,
+0x33,
 0x33,
 0x33,
 0x13,
 0x11,
-0x41,
+0x32,
+0x12,
+0x13,
+0x13,
+0x34,
+0x34,
+0x32,
+0x33,
+0x11,
+0x12,
+0x33,
+0x31,
+0x21,
+0x33,
+0x31,
+0x31,
+0x23,
+0x31,
+0x11,
+0x32,
+0x22,
+0x12,
+0x22,
+0x13,
+0x33,
 0x34,
 0x33,
 0x33,
-0x41,
-0x33,
-0x13,
 0x31,
-0x11,
-0x41,
-0x33,
-0x41,
-0x33,
-0x11,
-0x11,
-0x33,
-0x33,
-0x43,
-0x41,
-0x31,
-0x12,
-0x33,
-0x23,
-0x32,
-0x33,
-0x12,
-0x11,
-0x22,
-0x33,
-0x13,
-0x32,
-0x22,
-0x42,
-0x32,
-0x31,
-0x13,
-0x33,
-0x32,
-0x33,
-0x11,
-0x10,
-0x24,
 0x13,
 0x23,
-0x12,
-0x33,
-0x33,
-0x31,
-0x21,
+0x34,
 0x11,
-0x11,
-0x21,
-0x13,
 0x31,
 0x33,
 0x33,
-0x33,
-0x11,
-0x21,
-0x23,
-0x31,
-0x31,
-0x41,
-0x43,
-0x23,
-0x13,
-0x21,
-0x31,
-0x13,
-0x13,
-0x32,
-0x13,
-0x13,
-0x33,
-0x12,
-0x13,
-0x21,
-0x23,
-0x22,
-0x21,
-0x32,
-0x31,
-0x43,
-0x33,
-0x33,
-0x13,
-0x33,
-0x31,
-0x42,
-0x13,
-0x11,
-0x33,
-0x33,
-0x33,
 0x31,
 0x23,
 0x31,
